<?php

/**
 * Documentation page rendering for Link Loom
 *
 * @package LinkLoom
 * @subpackage Admin
 */

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Render the Documentation page.
 */
function linkloom_render_documentation_page() {
    if (!current_user_can('manage_options')) {
        wp_die(esc_html__('Unauthorized user', 'link-loom-seo-internal-link-builder'));
    }
    ?>
    <div class="wrap linkloom-admin-page">
        <h1><?php echo esc_html__('Documentation', 'link-loom-seo-internal-link-builder'); ?></h1>
        <div class="card">
            <h2><?php echo esc_html__('Getting Started', 'link-loom-seo-internal-link-builder'); ?></h2>
            <p><?php echo esc_html__('Link Loom makes internal linking simple and effective. Here\'s everything you need to know:', 'link-loom-seo-internal-link-builder'); ?></p>
            
            <h3><?php echo esc_html__('1. Basic Link Creation', 'link-loom-seo-internal-link-builder'); ?></h3>
            <ul>
                <li><?php echo esc_html__('Go to Settings and enter your keyword mappings', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Use "keyword|URL" for simple one-way links (do not include the quotes)', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Use "keyword|URLto|URLfrom" to specify exact page connections (do not include the quotes)', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Each keyword automatically becomes a link when found in your content', 'link-loom-seo-internal-link-builder'); ?></li>
            </ul>

            <h3><?php echo esc_html__('2. Advanced Controls', 'link-loom-seo-internal-link-builder'); ?></h3>
            <ul>
                <li><?php echo esc_html__('Choose which occurrence to link: first, last, or random', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Set global limits to control links per page', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Use fixed numbers or random ranges for link limits', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('All features are included with unlimited keyword mappings', 'link-loom-seo-internal-link-builder'); ?></li>
            </ul>

            <h3><?php echo esc_html__('3. Smart Features', 'link-loom-seo-internal-link-builder'); ?></h3>
            <ul>
                <li><?php echo esc_html__('Use LinkMap to discover natural linking opportunities', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Get keyword suggestions based on your content', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Create organized internal linking structures', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Preview and select from multiple linking options', 'link-loom-seo-internal-link-builder'); ?></li>
            </ul>

            <h3><?php echo esc_html__('4. Best Practices', 'link-loom-seo-internal-link-builder'); ?></h3>
            <ul>
                <li><?php echo esc_html__('Choose keywords that appear naturally in your content', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Use specific phrases rather than generic terms', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Ensure your links create meaningful connections', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Start with a few links and expand gradually', 'link-loom-seo-internal-link-builder'); ?></li>
                <li><?php echo esc_html__('Use LinkMap to maintain a clean link structure', 'link-loom-seo-internal-link-builder'); ?></li>
            </ul>
        </div>
    </div>
    <?php
}
