<?php

/**
 * Cache utility functions for Link Loom
 *
 * @package LinkLoom
 * @subpackage Utils
 */

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Get a cache key for content processing based on post ID and settings.
 *
 * @param int   $post_id  Post ID.
 * @param array $settings Plugin settings.
 * @return string Cache key.
 */
function linkloom_get_cache_key($post_id, $settings) {
    // Create a hash of relevant settings
    $settings_hash = md5(serialize(array(
        'mappings' => $settings['mappings'],
        'instance_selection' => $settings['instance_selection'],
        'global_limit_mode' => $settings['global_limit_mode'],
        'global_limit_fixed' => $settings['global_limit_fixed'],
        'global_limit_min' => $settings['global_limit_min'],
        'global_limit_max' => $settings['global_limit_max']
    )));
    
    return 'linkloom_content_' . $post_id . '_' . $settings_hash;
}

/**
 * Track transient keys for easier cleanup.
 *
 * @param string $key The transient key to track.
 */
function linkloom_track_transient($key) {
    $tracked_keys = get_option('linkloom_tracked_transients', array());
    if (!in_array($key, $tracked_keys)) {
        $tracked_keys[] = $key;
        update_option('linkloom_tracked_transients', $tracked_keys);
    }
}

/**
 * Clear content cache when a post is updated or settings change.
 *
 * @param int|null $post_id Optional post ID to clear specific cache.
 */
function linkloom_clear_cache($post_id = null) {
    if ($post_id) {
        // Clear specific post cache
        $settings = get_option('linkloom_settings', array());
        $cache_key = linkloom_get_cache_key($post_id, $settings);
        delete_transient($cache_key);
    } else {
        // Clear all Link Loom transients using tracked keys
        $tracked_keys = get_option('linkloom_tracked_transients', array());
        foreach ($tracked_keys as $key) {
            delete_transient($key);
        }
        // Reset tracked keys
        update_option('linkloom_tracked_transients', array());
    }
}
