<?php

/**
 * Sanitization utility functions for Link Loom
 *
 * @package LinkLoom
 * @subpackage Utils
 */

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Sanitize and validate mapping input.
 *
 * @param string $mappings_raw Raw mappings input from textarea.
 * @return array Sanitized mappings array.
 */
function linkloom_sanitize_mappings($mappings_raw) {
    $mappings_array = array();
    $lines = explode("\n", $mappings_raw);
    
    foreach ($lines as $line) {
        $line = trim($line);
        if (empty($line)) {
            continue;
        }
        
        $parts_line = explode('|', $line);
        if (count($parts_line) === 2) {
            $keyword = sanitize_text_field($parts_line[0]);
            $url = esc_url_raw(trim($parts_line[1]));
            if (!empty($keyword) && !empty($url)) {
                $mappings_array[$keyword] = $url;
            }
        } elseif (count($parts_line) === 3) {
            $keyword = sanitize_text_field($parts_line[0]);
            $urlto = esc_url_raw(trim($parts_line[1]));
            $urlfrom = esc_url_raw(trim($parts_line[2]));
            if (!empty($keyword) && !empty($urlto) && !empty($urlfrom)) {
                $mappings_array[$keyword] = array('urlto' => $urlto, 'urlfrom' => $urlfrom);
            }
        }
    }
    
    return $mappings_array;
}

/**
 * Validate and sanitize plugin settings.
 *
 * @param array $input Raw settings input.
 * @return array Sanitized settings.
 */
function linkloom_sanitize_settings($input) {
    $defaults = array(
        'mappings' => array(),
        'instance_selection' => 'first',
        'global_limit_mode' => 'fixed',
        'global_limit_fixed' => 1,
        'global_limit_min' => 1,
        'global_limit_max' => 1,
    );

    $output = wp_parse_args($input, $defaults);

    // Validate instance selection
    if (!in_array($output['instance_selection'], array('first', 'last', 'random'))) {
        $output['instance_selection'] = 'first';
    }

    // Validate global limit mode
    if (!in_array($output['global_limit_mode'], array('fixed', 'random'))) {
        $output['global_limit_mode'] = 'fixed';
    }

    // Ensure numeric values are positive integers
    $output['global_limit_fixed'] = max(0, intval($output['global_limit_fixed']));
    $output['global_limit_min'] = max(0, intval($output['global_limit_min']));
    $output['global_limit_max'] = max($output['global_limit_min'], intval($output['global_limit_max']));

    return $output;
}
