<?php

/*
Plugin Name: Link Loom: SEO Internal Link Builder
Plugin URI: https://rivexor.com/link-loom-seo-internal-link-builder/
Description: Link Loom: SEO Internal Link Builder by Rivexor automatically converts specified keywords in your WordPress content into internal links to boost your site's SEO and improve navigation. Choose which occurrence to link (first, last, or random) and enforce a global limit on distinct keyword links per page.
Version: 1.8.3
Author: Rivexor
Author URI: https://rivexor.com
License: GPL v2 or later
Text Domain: link-loom-seo-internal-link-builder
*/

if (!defined('ABSPATH')) {
    exit;
}

// Define plugin constants
define('LINKLOOM_VERSION', '1.8.3');
define('LINKLOOM_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('LINKLOOM_PLUGIN_URL', plugin_dir_url(__FILE__));

// Load required files
require_once LINKLOOM_PLUGIN_DIR . 'includes/utils/cache.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/utils/sanitization.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/content-processor.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/admin/menu.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/admin/settings.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/admin/documentation.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/admin/linkmap.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/linkmap/batch-processor.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/linkmap/graph-analyzer.php';
require_once LINKLOOM_PLUGIN_DIR . 'includes/linkmap/generator.php';

// Load plugin text domain for internationalization
function linkloom_load_textdomain() {
    load_plugin_textdomain('link-loom-seo-internal-link-builder', false, dirname(plugin_basename(__FILE__)) . '/languages');
}
add_action('plugins_loaded', 'linkloom_load_textdomain');

// Hook the content filter
add_filter('the_content', 'linkloom_filter_content_global');

// Register activation/deactivation hooks
register_activation_hook(__FILE__, 'linkloom_activate');
register_deactivation_hook(__FILE__, 'linkloom_deactivate');
register_uninstall_hook(__FILE__, 'linkloom_uninstall');

/**
 * Plugin activation hook.
 */
function linkloom_activate() {
    // Initialize default settings if they don't exist
    if (!get_option('linkloom_settings')) {
        $default_settings = array(
            'mappings' => array(),
            'instance_selection' => 'first',
            'global_limit_mode' => 'fixed',
            'global_limit_fixed' => 1,
            'global_limit_min' => 1,
            'global_limit_max' => 1,
        );
        update_option('linkloom_settings', $default_settings);
    }
}

/**
 * Plugin deactivation hook.
 */
function linkloom_deactivate() {
    // Clear all transients
    linkloom_clear_cache();
}

/**
 * Plugin uninstall hook.
 */
function linkloom_uninstall() {
    // Clean up tracked transients
    $tracked_keys = get_option('linkloom_tracked_transients', array());
    foreach ($tracked_keys as $key) {
        delete_transient($key);
    }
    
    // Remove all plugin options
    delete_option('linkloom_tracked_transients');
    delete_option('linkloom_settings');
}

// Hook cache clearing to relevant actions
add_action('save_post', 'linkloom_clear_cache');
add_action('update_option_linkloom_settings', function() { 
    linkloom_clear_cache(); 
});
